@@ -2,11 +2,12 @@ import re
 from thefuck.specific.git import git_support
 
 error_pattern = "fatal: bad flag '(.*?)' used after filename"
+error_pattern2 = "fatal: option '(.*?)' must come before non-option arguments"
 
 
 @git_support
 def match(command):
-    return re.search(error_pattern, command.output)
+    return re.search(error_pattern, command.output) or re.search(error_pattern2, command.output)
 
 
 @git_support
@@ -14,7 +15,7 @@ def get_new_command(command):
     command_parts = command.script_parts[:]
 
     # find the bad flag
-    bad_flag = re.search(error_pattern, command.output).group(1)
+    bad_flag = match(command).group(1)
     bad_flag_index = command_parts.index(bad_flag)
 
     # find the filename
